@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: BSD-2-Clause
 
-# Copyright (c) 2025 Phil Thompson <phil@riverbankcomputing.com>
+# Copyright (c) 2024 Phil Thompson <phil@riverbankcomputing.com>
 
 
 from abc import abstractmethod
@@ -14,8 +14,8 @@ from .abstract_builder import AbstractBuilder
 from .distinfo import write_metadata
 from .exceptions import UserException
 from .installable import Installable
-from .module import copy_sip_h, copy_sip_pyi, get_latest_version
-from .py_versions import DEFAULT_ABI_MAJOR, OLDEST_SUPPORTED_MINOR
+from .module import copy_sip_h, copy_sip_pyi
+from .py_versions import OLDEST_SUPPORTED_MINOR
 
 
 class Builder(AbstractBuilder):
@@ -48,7 +48,8 @@ class Builder(AbstractBuilder):
         project = self.project
 
         # The sdist name.
-        sdist_name = project.normalized_name
+        sdist_name = '{}-{}'.format(project.name.replace('-', '_'),
+                project.version_str)
 
         # Create the sdist root directory.
         sdist_root = os.path.join(project.build_dir, sdist_name)
@@ -83,13 +84,6 @@ class Builder(AbstractBuilder):
 
                 shutil.copy2(s_fn_path, d_fn_path)
 
-        # If we don't know the target ABI at this point then default to the
-        # latest version.
-        if project.target_abi is None:
-            major_version = DEFAULT_ABI_MAJOR
-            minor_version = get_latest_version(major_version)
-            project.target_abi = (major_version, minor_version)
-
         # Create the PKG-INFO file.  This is assumed to be identical to the
         # .dist-info/METADATA file.
         write_metadata(project.metadata, project.get_requires_dists(),
@@ -170,36 +164,28 @@ class Builder(AbstractBuilder):
         # Copy the wheel contents.
         self.install_project(wheel_build_dir, wheel_tag=wheel_tag)
 
-        wheel_file = [project.normalized_name]
+        wheel_file = '{}-{}'.format(project.name.replace('-', '_'),
+                project.version_str)
 
         if project.build_tag:
-            wheel_file.append(project.build_tag)
+            wheel_file += '-{}'.format(project.build_tag)
 
-        wheel_file.append(wheel_tag)
-        wheel_file = '-'.join(wheel_file) + '.whl'
+        wheel_file += '-{}.whl'.format(wheel_tag)
         wheel_path = os.path.abspath(os.path.join(wheel_directory, wheel_file))
 
         # Create the .whl file.
         saved_cwd = os.getcwd()
         os.chdir(wheel_build_dir)
 
-        import time 
-        from zipfile import ZipFile, ZipInfo, ZIP_DEFLATED
+        from zipfile import ZipFile, ZIP_DEFLATED
 
-        # Ensure reproducible wheel file timestamps
-        epoch = int(os.environ.get('SOURCE_DATE_EPOCH', time.time()))
-        zip_timestamp = time.gmtime(epoch)[:6]
-
-        with ZipFile(wheel_path, 'w') as zf:
+        with ZipFile(wheel_path, 'w', compression=ZIP_DEFLATED) as zf:
             for dirpath, _, filenames in os.walk('.'):
                 for filename in filenames:
                     # This will result in a name with no leading '.'.
                     name = os.path.relpath(os.path.join(dirpath, filename))
 
-                    zi = ZipInfo(name, zip_timestamp)
-
-                    with open(name, 'rb') as f:
-                        zf.writestr(zi, f.read(), compress_type=ZIP_DEFLATED)
+                    zf.write(name)
 
         os.chdir(saved_cwd)
 
@@ -224,6 +210,8 @@ class Builder(AbstractBuilder):
 
         project = self.project
 
+        abi_major_version, _ = project.abi_version.split('.')
+
         # Get the list of directories to search for .sip files.
         sip_include_dirs = list(project.sip_include_dirs)
 
@@ -241,6 +229,10 @@ class Builder(AbstractBuilder):
                     os.path.join(project.target_dir,
                             project.get_bindings_dir()))
 
+            # Generate the sip.h file for the shared sip module.
+            copy_sip_h(abi_major_version, project.build_dir,
+                    project.sip_module, version_info=project.version_info)
+
         # Generate the code for each set of bindings.
         api_files = []
 
@@ -266,12 +258,6 @@ class Builder(AbstractBuilder):
 
             project.buildables.append(buildable)
 
-        if project.sip_module:
-            # Generate the sip.h file for the shared sip module now that we
-            # know the target ABI.
-            copy_sip_h(project.build_abi, project.sip_module,
-                    project.build_dir, version_info=project.version_info)
-
         # Create __init__.py if required.
         if project.dunder_init:
             package_dir = project.get_package_dir()
@@ -289,7 +275,7 @@ class Builder(AbstractBuilder):
             # Include sip.pyi if any of the bindings generate a .pyi file.
             for bindings in project.bindings.values():
                 if bindings.pep484_pyi:
-                    copy_sip_pyi(project.build_abi, project.build_dir)
+                    copy_sip_pyi(abi_major_version, project.build_dir)
 
                     installable = Installable('sip_pyi',
                             target_subdir=package_dir)
